@@ -4,6 +4,7 @@ package Vimana::Command::Install;
 use base qw(App::CLI::Command);
 use URI;
 use LWP::Simple qw();
+use File::Path qw(rmtree);
 
 require Vimana::VimOnline;
 require Vimana::VimOnline::ScriptPage;
@@ -74,10 +75,23 @@ NEXT_DEP_FILE:
     return @ins_type;
 }
 
+use Cwd;
+
 sub install_by_strategy {
     my ( $self, $pkgfile, $tmpdir, $args ) = @_;
+
+    my $prev_dir = getcwd();
+    chdir($tmpdir);
     my $ret;
     my @ins_type = $self->check_strategies( 
+        {
+            name => 'Makefile',
+            desc => q{Check if makefile exists.},
+            installer => 'Makefile',
+            deps => [qw(makefile Makefile)],
+        },
+        # because Meta file would overwrite "Makefile" file. so put Meta file
+        # after Makefile strategy
         {
             name => 'Meta',
             desc => q{Check if 'META' or 'VIMMETA' file exists. support for VIM::Packager.},
@@ -85,12 +99,6 @@ sub install_by_strategy {
             deps =>  [qw(VIMMETA META)],
             bin =>  [qw(vim-packager)],
         },
-        {
-            name => 'Makefile',
-            desc => q{Check if makefile exists.},
-            installer => 'Makefile',
-            deps => [qw(makefile Makefile)],
-        },
         {
             name => 'Rakefile',
             desc => q{Check if rakefile exists.},
@@ -126,6 +134,12 @@ DONE:
         return $ret;
     }
 
+    chdir($prev_dir);
+    if( $args->{cleanup} ) {
+        $logger->info("Cleaning up temporary directory.");
+        rmtree [ $tmpdir ] if -e $tmpdir;
+    }
+
     $logger->info( "Succeed." );
     return $ret;
 }
@@ -175,13 +189,11 @@ END
             $cmd = 'svn co';
         }
         system(qq{$cmd $uri $dir});
-        chdir $dir;
         return $self->install_by_strategy( undef, $dir, 
             { cleanup => 1 , 
               runtime_path => $self->{runtime_path} } );
     }
     elsif( $arg eq '.' ) {
-        chdir '.';
         return $self->install_by_strategy( undef, '.',
             { cleanup => 0  , 
               runtime_path => $self->{runtime_path} } );
@@ -237,8 +249,6 @@ END
                     package => $pkgfile , 
                     runtime_path => $self->{runtime_path} } );
             $ret = $installer->run( $pkgfile );
-
-
         }
         elsif( $pkgfile->is_archive ) {
 
@@ -249,7 +259,6 @@ END
             $pkgfile->extract_to( $tmpdir );
             $logger->info("Changing directory to $tmpdir.");
 
-            chdir $tmpdir;
             $ret = $self->install_by_strategy( $pkgfile, $tmpdir,
                 { cleanup => 1, 
                   runtime_path => $self->{runtime_path} } );
